pub struct CtapProcessCbor {
pub cmd: u8,
pub raw: Vec<u8>,
}Fields
cmd: u8raw: Vec<u8>Trait Implementations
Sourceimpl Archive for CtapProcessCbor
impl Archive for CtapProcessCbor
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedCtapProcessCbor
type Archived = ArchivedCtapProcessCbor
The archived representation of this type. Read more
Sourcetype Resolver = CtapProcessCborResolver
type Resolver = CtapProcessCborResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for CtapProcessCbor
impl BlockingArchive for CtapProcessCbor
Sourceimpl Clone for CtapProcessCbor
impl Clone for CtapProcessCbor
Sourcefn clone(&self) -> CtapProcessCbor
fn clone(&self) -> CtapProcessCbor
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CtapProcessCbor
impl Debug for CtapProcessCbor
Sourceimpl<__D: Fallible + ?Sized> Deserialize<CtapProcessCbor, __D> for Archived<CtapProcessCbor>
impl<__D: Fallible + ?Sized> Deserialize<CtapProcessCbor, __D> for Archived<CtapProcessCbor>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<CtapProcessCbor, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<CtapProcessCbor, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for CtapProcessCbor
impl MessageId for CtapProcessCbor
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for CtapProcessCbor
impl<__S: Fallible + ?Sized> Serialize<__S> for CtapProcessCbor