pub struct EditSecurityKey {
pub index: usize,
pub label: String,
pub color: u8,
pub icon: String,
pub date: u64,
}Expand description
Edit metadata of an existing security key. Returns the validation outcome so the GUI
can surface EmptyLabel/DuplicateLabel without a separate validate_label round-trip.
Fields
index: usizelabel: Stringcolor: u8icon: Stringdate: u64Trait Implementations
Sourceimpl Archive for EditSecurityKey
impl Archive for EditSecurityKey
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedEditSecurityKey
type Archived = ArchivedEditSecurityKey
The archived representation of this type. Read more
Sourcetype Resolver = EditSecurityKeyResolver
type Resolver = EditSecurityKeyResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for EditSecurityKey
impl BlockingArchive for EditSecurityKey
Sourceimpl Clone for EditSecurityKey
impl Clone for EditSecurityKey
Sourcefn clone(&self) -> EditSecurityKey
fn clone(&self) -> EditSecurityKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EditSecurityKey
impl Debug for EditSecurityKey
Sourceimpl<__D: Fallible + ?Sized> Deserialize<EditSecurityKey, __D> for Archived<EditSecurityKey>
impl<__D: Fallible + ?Sized> Deserialize<EditSecurityKey, __D> for Archived<EditSecurityKey>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<EditSecurityKey, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<EditSecurityKey, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for EditSecurityKey
impl MessageId for EditSecurityKey
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for EditSecurityKey
impl<__S: Fallible + ?Sized> Serialize<__S> for EditSecurityKey