pub struct KeysChangedEvent {
pub keys: Vec<SecurityKeyView>,
}Expand description
Wrapper for the key list published via events.
Fields
keys: Vec<SecurityKeyView>Trait Implementations
Sourceimpl Archive for KeysChangedEventwhere
Vec<SecurityKeyView>: Archive,
impl Archive for KeysChangedEventwhere
Vec<SecurityKeyView>: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedKeysChangedEvent
type Archived = ArchivedKeysChangedEvent
The archived representation of this type. Read more
Sourcetype Resolver = KeysChangedEventResolver
type Resolver = KeysChangedEventResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for KeysChangedEvent
impl Clone for KeysChangedEvent
Sourcefn clone(&self) -> KeysChangedEvent
fn clone(&self) -> KeysChangedEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KeysChangedEvent
impl Debug for KeysChangedEvent
Sourceimpl<__D: Fallible + ?Sized> Deserialize<KeysChangedEvent, __D> for Archived<KeysChangedEvent>where
Vec<SecurityKeyView>: Archive,
<Vec<SecurityKeyView> as Archive>::Archived: Deserialize<Vec<SecurityKeyView>, __D>,
impl<__D: Fallible + ?Sized> Deserialize<KeysChangedEvent, __D> for Archived<KeysChangedEvent>where
Vec<SecurityKeyView>: Archive,
<Vec<SecurityKeyView> as Archive>::Archived: Deserialize<Vec<SecurityKeyView>, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<KeysChangedEvent, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<KeysChangedEvent, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for KeysChangedEventwhere
Vec<SecurityKeyView>: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for KeysChangedEventwhere
Vec<SecurityKeyView>: Serialize<__S>,