pub struct OperationOutcomeEvent {
pub security_key_index: usize,
pub operation: OperationType,
pub success: bool,
}Expand description
Event published by the FIDO server after a U2F/CTAP operation completes (success or failure). The Security Keys app is the only subscriber: it shows the success/failure modal in response. At outcome time the app is guaranteed running (it just handled the presence prompt), so a subscription is sufficient.
Fields
security_key_index: usizeoperation: OperationTypesuccess: boolTrait Implementations
Sourceimpl Archive for OperationOutcomeEvent
impl Archive for OperationOutcomeEvent
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedOperationOutcomeEvent
type Archived = ArchivedOperationOutcomeEvent
The archived representation of this type. Read more
Sourcetype Resolver = OperationOutcomeEventResolver
type Resolver = OperationOutcomeEventResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for OperationOutcomeEvent
impl Clone for OperationOutcomeEvent
Sourcefn clone(&self) -> OperationOutcomeEvent
fn clone(&self) -> OperationOutcomeEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OperationOutcomeEvent
impl Debug for OperationOutcomeEvent
Sourceimpl<__D: Fallible + ?Sized> Deserialize<OperationOutcomeEvent, __D> for Archived<OperationOutcomeEvent>where
usize: Archive,
<usize as Archive>::Archived: Deserialize<usize, __D>,
OperationType: Archive,
<OperationType as Archive>::Archived: Deserialize<OperationType, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
impl<__D: Fallible + ?Sized> Deserialize<OperationOutcomeEvent, __D> for Archived<OperationOutcomeEvent>where
usize: Archive,
<usize as Archive>::Archived: Deserialize<usize, __D>,
OperationType: Archive,
<OperationType as Archive>::Archived: Deserialize<OperationType, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<OperationOutcomeEvent, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<OperationOutcomeEvent, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for OperationOutcomeEvent
impl<__S: Fallible + ?Sized> Serialize<__S> for OperationOutcomeEvent