pub struct PresenceKeepAliveEvent {
pub fingerprint: [u8; 32],
}Expand description
Heartbeat published by the FIDO server every time it replies to an RP with a “retry me”
status (ConditionNotSatisfied for U2F, UserActionPending for CTAP2). Subscribers — the
Security Keys app while its user-presence modal is up — use these to distinguish an active
RP from an abandoned one and auto-dismiss the modal when the heartbeat stops.
The fingerprint is the SHA-256 of the current in-flight request, exposed so the UI can ignore heartbeats for a different fingerprint if a newer request has taken over.
Fields
fingerprint: [u8; 32]Trait Implementations
Sourceimpl Archive for PresenceKeepAliveEvent
impl Archive for PresenceKeepAliveEvent
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedPresenceKeepAliveEvent
type Archived = ArchivedPresenceKeepAliveEvent
The archived representation of this type. Read more
Sourcetype Resolver = PresenceKeepAliveEventResolver
type Resolver = PresenceKeepAliveEventResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for PresenceKeepAliveEvent
impl Clone for PresenceKeepAliveEvent
Sourcefn clone(&self) -> PresenceKeepAliveEvent
fn clone(&self) -> PresenceKeepAliveEvent
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PresenceKeepAliveEvent
impl Debug for PresenceKeepAliveEvent
Sourceimpl<__D: Fallible + ?Sized> Deserialize<PresenceKeepAliveEvent, __D> for Archived<PresenceKeepAliveEvent>
impl<__D: Fallible + ?Sized> Deserialize<PresenceKeepAliveEvent, __D> for Archived<PresenceKeepAliveEvent>
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<PresenceKeepAliveEvent, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<PresenceKeepAliveEvent, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for PresenceKeepAliveEvent
impl<__S: Fallible + ?Sized> Serialize<__S> for PresenceKeepAliveEvent