pub struct U2fProcessApdu {
pub command: U2fApduCommand,
pub transport: Transport,
}Fields
command: U2fApduCommandtransport: TransportTrait Implementations
Sourceimpl Archive for U2fProcessApduwhere
U2fApduCommand: Archive,
Transport: Archive,
impl Archive for U2fProcessApduwhere
U2fApduCommand: Archive,
Transport: Archive,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedU2fProcessApdu
type Archived = ArchivedU2fProcessApdu
The archived representation of this type. Read more
Sourcetype Resolver = U2fProcessApduResolver
type Resolver = U2fProcessApduResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl BlockingArchive for U2fProcessApdu
impl BlockingArchive for U2fProcessApdu
Sourceimpl Clone for U2fProcessApdu
impl Clone for U2fProcessApdu
Sourcefn clone(&self) -> U2fProcessApdu
fn clone(&self) -> U2fProcessApdu
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for U2fProcessApdu
impl Debug for U2fProcessApdu
Sourceimpl<__D: Fallible + ?Sized> Deserialize<U2fProcessApdu, __D> for Archived<U2fProcessApdu>where
U2fApduCommand: Archive,
<U2fApduCommand as Archive>::Archived: Deserialize<U2fApduCommand, __D>,
Transport: Archive,
<Transport as Archive>::Archived: Deserialize<Transport, __D>,
impl<__D: Fallible + ?Sized> Deserialize<U2fProcessApdu, __D> for Archived<U2fProcessApdu>where
U2fApduCommand: Archive,
<U2fApduCommand as Archive>::Archived: Deserialize<U2fApduCommand, __D>,
Transport: Archive,
<Transport as Archive>::Archived: Deserialize<Transport, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<U2fProcessApdu, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<U2fProcessApdu, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl MessageId for U2fProcessApdu
impl MessageId for U2fProcessApdu
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for U2fProcessApduwhere
U2fApduCommand: Serialize<__S>,
Transport: Serialize<__S>,
impl<__S: Fallible + ?Sized> Serialize<__S> for U2fProcessApduwhere
U2fApduCommand: Serialize<__S>,
Transport: Serialize<__S>,