pub struct SecurityKeyView {
pub index: usize,
pub label: String,
pub color: u8,
pub icon: String,
pub archived: bool,
pub live: bool,
pub date: u64,
pub registered_count: usize,
}Expand description
View of a SecurityKey exposed to UI clients via IPC. Must be serializable with rkyv for archive events/messages.
Fields
index: usizelabel: Stringcolor: u8icon: Stringarchived: boollive: booldate: u64registered_count: usizeTrait Implementations
Sourceimpl Archive for SecurityKeyView
impl Archive for SecurityKeyView
Sourceconst COPY_OPTIMIZATION: CopyOptimization<Self>
const COPY_OPTIMIZATION: CopyOptimization<Self>
An optimization flag that allows the bytes of this type to be copied
directly to a writer instead of calling
serialize. Read moreSourcetype Archived = ArchivedSecurityKeyView
type Archived = ArchivedSecurityKeyView
The archived representation of this type. Read more
Sourcetype Resolver = SecurityKeyViewResolver
type Resolver = SecurityKeyViewResolver
The resolver for this type. It must contain all the additional
information from serializing needed to make the archived type from
the normal type.
Sourceimpl Clone for SecurityKeyView
impl Clone for SecurityKeyView
Sourcefn clone(&self) -> SecurityKeyView
fn clone(&self) -> SecurityKeyView
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SecurityKeyView
impl Debug for SecurityKeyView
Sourceimpl<'de> Deserialize<'de> for SecurityKeyView
impl<'de> Deserialize<'de> for SecurityKeyView
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<__D: Fallible + ?Sized> Deserialize<SecurityKeyView, __D> for Archived<SecurityKeyView>where
usize: Archive,
<usize as Archive>::Archived: Deserialize<usize, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
u8: Archive,
<u8 as Archive>::Archived: Deserialize<u8, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
impl<__D: Fallible + ?Sized> Deserialize<SecurityKeyView, __D> for Archived<SecurityKeyView>where
usize: Archive,
<usize as Archive>::Archived: Deserialize<usize, __D>,
String: Archive,
<String as Archive>::Archived: Deserialize<String, __D>,
u8: Archive,
<u8 as Archive>::Archived: Deserialize<u8, __D>,
bool: Archive,
<bool as Archive>::Archived: Deserialize<bool, __D>,
u64: Archive,
<u64 as Archive>::Archived: Deserialize<u64, __D>,
Sourcefn deserialize(
&self,
deserializer: &mut __D,
) -> Result<SecurityKeyView, <__D as Fallible>::Error>
fn deserialize( &self, deserializer: &mut __D, ) -> Result<SecurityKeyView, <__D as Fallible>::Error>
Deserializes using the given deserializer
Sourceimpl<__S: Fallible + ?Sized> Serialize<__S> for SecurityKeyView
impl<__S: Fallible + ?Sized> Serialize<__S> for SecurityKeyView